package
Version:
v0.0.0-...-fe09838
Opens a new window with list of versions in this module.
Published: Jun 15, 2025
License: BSD-3-Clause
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 1
Opens a new window with list of known importers.
Documentation
¶
type DB struct {
Schema string `yaml:"schema"`
User string `yaml:"user"`
Password string `yaml:"password"`
IP string `yaml:"ip"`
Port uint16 `yaml:"port"`
DataBase string `yaml:"database"`
SSL string `yaml:"ssl"`
MigrationsPath string `yaml:"migrations_path"`
}
DB ...
Driver ...
const (
PGDriver Driver = "postgres"
)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.